@@ -58,7 +58,7 @@ class CorsPlugin:
         def wrapped_handler(*args, **kwargs):
             response.headers['Access-Control-Allow-Origin'] = self._origins
             response.headers['Access-Control-Allow-Methods'] = 'GET, POST, PUT, OPTIONS'
-            response.headers['Access-Control-Allow-Headers'] = 'Origin, Accept, Content-Type, X-Requested-With, X-api-key',
+            response.headers['Access-Control-Allow-Headers'] = 'Origin, Accept, Content-Type, X-Requested-With, X-api-key'
             if request.method != OPTIONS:
                 return handler(*args, **kwargs)
         return wrapped_handler
