@@ -245,6 +245,10 @@ def mk_http_service(funcs, **configs):
         app = Bottle(catchall=False)
         enable_cors = mk_config('enable_cors', None, configs, default_configs)
         plugins = mk_config('plugins', None, configs, default_configs)
+        if enable_cors:
+            cors_allowed_origins = mk_config('cors_allowed_origins', None, configs, default_configs)
+            print(f'install cors for origins {cors_allowed_origins}', flush=True)
+            plugins = [CorsPlugin(cors_allowed_origins), *plugins]
         publish_openapi = mk_config('publish_openapi', None, configs, default_configs)
         openapi_insecure = mk_config('openapi_insecure', None, configs, default_configs)
         if plugins:
@@ -264,7 +268,6 @@ def mk_http_service(funcs, **configs):
         return app
 
     def mk_aiohttp_service():
-
         middleware = mk_config('middleware', None, configs, default_configs)
         app = web.Application(middlewares=middleware)
         app.add_routes([
@@ -320,10 +323,6 @@ def run_many_services(apps, run_now=False, **configs):
 def run_many_bottle_services(apps, run_now=False, **configs):
     from bottle import Bottle, run
     parent_app = Bottle(catchall=False)
-    enable_cors = mk_config('enable_cors', None, configs, default_configs)
-    cors_allowed_origins = mk_config('cors_allowed_origins', None, configs, default_configs)
-    if enable_cors:
-        parent_app.install(CorsPlugin(cors_allowed_origins))
     for route, subapp in apps.items():
         parent_app.mount(route, subapp)
     if run_now:
